@@ -10,7 +10,8 @@ __PACKAGE__->load_namespaces(
     default_resultset_class => 'ResultSet',
 );
 
-our $VERSION = 38; # schema version used for upgrades, keep as integer
+our # try to hide from kwalitee
+  $VERSION = 38; # schema version used for upgrades, keep as integer
 
 use Path::Class;
 use File::Basename;
